@@ -51,64 +51,61 @@ ukair_get_coordinates.character <- function(ids){
 
   # return a data.frame with coordinates
   return(tibble::as_tibble(df))
-  
+
 }
 
 #' @export
 ukair_get_coordinates.data.frame <- function(ids){
-  
+
   if ("Northing" %in% names(ids) & "Easting" %in% names(ids)){
-    
+
     # We expect to infill only missing coordinates
     nrows <- which(is.na(ids$Northing) | is.na(ids$Easting))
-    
+
   }else{
-    
+
     # otherwise, we force to extract coordinates for all the given stations
     ids$Northing <- NA
     ids$Easting <- NA
     nrows <- seq(1, dim(ids)[1])
-    
+
   }
-  
+
   # This is the list of all the relevant ids
   id_s <- as.character(ids$UK.AIR.ID[nrows])
-  
+
   df_extended <- data.frame(t(sapply(id_s, ukair_get_coordinates_internal)))
-  
+
   ids$Northing[nrows] <- df_extended$Northing
   ids$Easting[nrows] <- df_extended$Easting
   ids$Northing <- as.numeric(ids$Northing)
   ids$Easting <- as.numeric(ids$Easting)
-  
+
   df0 <- en2latlon(ids)
   df <- latlon2en(df0)
 
   return(tibble::as_tibble(df))
-  
+
 }
 
 #' Get Easting and Northing coordinates from DEFRA for 1 station
 #'
-#' @importFrom httr GET
-#' @importFrom xml2 xml_find_all
-#'
 #' @noRd
 #'
 
 ukair_get_coordinates_internal <- function(uka_id){
-  
+
   page_fetch <- httr::GET(url = "http://uk-air.defra.gov.uk",
                           path = "networks/site-info",
                           query = list(uka_id = uka_id))
-  
+
   # download content
   page_content <- httr::content(page_fetch)
-  
+
   # Extract tab row containing Easting and Northing
   page_tab <- xml2::xml_find_all(page_content,
                                  "//*[contains(@id,'tab_info')]")[[2]]
-  
+
   # extract and clean all the columns
   vals <- trimws(xml2::xml_text(page_tab))
   # Extract string containing easting and northing
@@ -116,27 +113,25 @@ ukair_get_coordinates_internal <- function(uka_id){
   x <- strsplit(x, "Latitude/Longitude:")[[1]][1]
   # split string into easting and northing and remove heading/trailing spaces
   en <- gsub("^\\s+|\\s+$", "", unlist(strsplit(x, ",")))
-  
+
   if (!is.null(en) & en[1] != "Not available" & en[2] != "Not available"){
-    
+
     en_numeric <- c("Easting" = as.numeric(en[1]),
                     "Northing" = as.numeric(en[2]))
-    
+
   }else{
-    
+
     en_numeric <- c("Easting" = NA, "Northing" = NA)
-    message(paste("No coordinates available for station", uka_id))
-    
+    # message(paste("No coordinates available for station", uka_id))
+
   }
-  
+
   return(en_numeric)
-  
+
 }
 
 #' Convert Easting and Northing to Latitude and Longitude
 #'
-#' @importFrom sp coordinates proj4string CRS spTransform
-#'
 #' @noRd
 #'
 
@@ -170,8 +165,6 @@ en2latlon <- function(df){
 
 #' Convert Latitude and Longitude to Easting and Northing
 #'
-#' @importFrom sp coordinates proj4string CRS spTransform
-#'
 #' @noRd
 #'
 
